@@ -5,17 +5,17 @@
 modname = 'cubicweb_skos'
 distname = 'cubicweb-skos'
 
-numversion = (2, 0, 0)
+numversion = (2, 2, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 description = '"SKOS implementation for cubicweb"'
-web = 'http://www.cubicweb.org/project/%s' % distname
+web = 'https://forge.extranet.logilab.fr/cubicweb/cubes/%s' % distname
 
 __depends__ = {
-    'cubicweb': '>= 3.26.0',
+    'cubicweb': ">= 3.26.0, < 3.37.0",
 }
 __recommends__ = {
     'rdflib': '>= 4.1',
